#
# spec file for package python-xcffib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-xcffib%{?psuffix}
Version:        1.5.0
Release:        2.1
Summary:        A drop in replacement for xpyb, an XCB python binding
License:        Apache-2.0
URL:            https://github.com/tych0/xcffib
Source:         https://files.pythonhosted.org/packages/source/x/xcffib/xcffib-%{version}.tar.gz
BuildRequires:  %{python_module cffi >= 1.1.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xcffib}
%endif
BuildRequires:  fdupes
BuildRequires:  libxcb-devel
BuildRequires:  python-rpm-macros
BuildRequires:  xeyes
BuildRequires:  xvfb-run
Requires:       python-cffi >= 1.1.0
BuildArch:      noarch
%python_subpackages

%description
The xcffib package is intended to be a (mostly) drop-in
replacement for xpyb.

%prep
%autosetup -p1 -n xcffib-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/xcffib/
%{python_sitelib}/xcffib-%{version}.dist-info
%endif

%changelog
* Fri Jun  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Wed Oct 18 2023 Soc Virnyl Estela <contact@uncomfyhalomacro.pl>
- update to 1.5.0:
  * build against xcb-proto 1.16.0 (Tycho Andersen)
  * add an automatic-github-releaser script
  * use cffi's in-line mode
  * build against xcb-proto 1.16.0
- remove python-xcffib-ffi-import.patch
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * remove leftover six import
  * module: expose additional xcb errors
  * Fix List.to_string()
- drop python-xcffib-six-leftover.patch (upstream)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Mar 23 2023 pgajdos@suse.com
- version update to 1.2.0
  * no upstream changelog found
- do not require six
- added patches
  fix https://github.com/tych0/xcffib/commit/8a488867d30464913706376ca3a9f4c98ca6c5cf
  + python-xcffib-six-leftover.patch
  fix ffi import [bsc#1209570c4]
  + python-xcffib-ffi-import.patch
* Tue Sep 27 2022 Markéta Machová <mmachova@suse.com>
- Update to 0.12.1
  * Replace nose by pytest
  * Allow the master xcb version to pass even if failing
  * drop Python 3.6, support Python 3.10
  * ci: test with new xcb 1.15 release
* Fri Jul 16 2021 Matej Cepl <mcepl@suse.com>
- Replace use of nose2 by pytest. There is no need to do anything
  else.
* Thu Jul  8 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.11.1
  * connection: don't automatically disconnect() on connection error
  * drop support for python 3.5
  * tests: switch to nose2
  * travis: test python 3.9
* Mon Oct 26 2020 John Vandenberg <jayvdb@gmail.com>
- Re-activate tests
- Update to 0.10.1
  * testing: handle lock file open() failures gracefully
- from v0.10.0
  * Drop support for Python 2.7
  * testing: protect find_display() with flock()
  * testing: don't leak discard FD
* Fri Feb 21 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests to avoid deadlock in xvfb
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.0
  * add Python 3.8
  * test: don't fail when there is no pre-existing display
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.8.1:
  * Testsuite expansion mostly
* Mon May  6 2019 pgajdos@suse.com
- version update to 0.8.0
  * Fix few more instances of inefficient struct format
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.0:
  * Various updates and fixes for ghc/cabal
  * Drop unnecessary imports
- Enable tests
* Thu Jan 24 2019 mvetter@suse.com
- Update to 0.6.0:
  * Depend on xcb-types 0.9.0
  * Fix spelling mistakes
  * Support the new eventstruct element
  * Use xcb-types HEAD instead of a released version
  * List: keep around the raw underlying represenation
  * Fix linter errors
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to 0.5.1.
- Implement single-spec version.
* Wed Nov 23 2016 hpj@urpla.net
- add python-cffi runtime dependency
* Mon Nov 21 2016 hpj@urpla.net
- version 0.4.2: initial build
